@@ -104,7 +104,7 @@ flames_create_full_ordertable(
     int intid=0;
     char outordtab[CATREC_LEN+5];
     int outtid=0;
-    orderpos *ordpos;
+    orderpos *ordpos=NULL;
 
     char **pointerstofree;
     int32_t npointerstofree=0;
@@ -125,19 +125,19 @@ flames_create_full_ordertable(
     int incols=0;
     int inrows=0;
     //  int instore=0;
-    int *indtype=0;
-    int *initems=0;
-    int *inbytes=0;
-    int *outcol=0;
+
+    int *initems=NULL;
+
+
     int inrow=0;
-    int incol=0;
+
     char inform[20];
     char inunit[80];
     char inlabel[80];
-    int *ibuffer=0;
-    float *fbuffer=0;
-    double *dbuffer=0;
-    char *cbuffer=0;
+
+
+
+
     int outordercol=0;
     int outfibrecol=0;
     int outxcol=0;
@@ -146,7 +146,7 @@ flames_create_full_ordertable(
     int outyfitcol=0;
     int outresidcol=0;
     int outrows=0;
-    int outcols=0;
+    //int outcols=0;
     int ifibre=0;
     int iorder=0;
     int found=0;
@@ -159,7 +159,7 @@ flames_create_full_ordertable(
     float fx=0;
     int outrow=0;
     char orderfibre[20];
-    int size=0;
+
 
     memset(inordtab, 0, CATREC_LEN+5);
     memset(outordtab, 0, CATREC_LEN+5);
@@ -383,6 +383,7 @@ overriding it");
             return flames_midas_fail();
         }
         /* loop over columns and create them exactly matching the input table */
+        int *indtype=NULL;
         if ((indtype = (int *) calloc((size_t) incols, sizeof(int)))==NULL) {
             SCTPUT("Error allocating memory in create_full_ordertable");
             if (freeordpos(ordpos)!=NOERR) {
@@ -409,7 +410,7 @@ overriding it");
             npointerstofree++;
             initems--;
         }
-
+        int *inbytes=NULL;
         if ((inbytes = (int *) calloc((size_t) incols, sizeof(int)))==NULL) {
             SCTPUT("Error allocating memory in create_full_ordertable");
             if (freeordpos(ordpos)!=NOERR) {
@@ -423,7 +424,7 @@ overriding it");
             npointerstofree++;
             inbytes--;
         }
-
+        int *outcol=0;
         if ((outcol =  calloc((size_t) 2*incols, sizeof(int)))==NULL) {
             SCTPUT("Error allocating memory in create_full_ordertable");
             if (freeordpos(ordpos)!=NOERR) {
@@ -437,6 +438,8 @@ overriding it");
             npointerstofree++;
             outcol--;
         }
+        int incol=0;
+        int size=0;
         for (incol=1; incol<=incols; incol++) {
             if (TCBGET(intid, incol, indtype+incol, initems+incol, inbytes+incol)
                             !=0) {
@@ -485,8 +488,10 @@ overriding it");
                 return flames_midas_fail();
             }
             /* create this column in the new table */
+
             switch(indtype[incol]) {
             case D_C_FORMAT:
+
                 size = initems[incol]*inbytes[incol];
                 break;
             case D_I1_FORMAT:
@@ -523,12 +528,15 @@ overriding it");
         }
         /* now we can proceed to copy all elements from the input table to the
        output table */
+        int *ibuffer=NULL;
+        float *fbuffer=NULL;
+        double *dbuffer=NULL;
         for (incol=1; incol<=incols; incol++) {
             /* allocate the temporary buffer for the single array in this column */
 
             uves_msg_debug("DType is %d  initems = %d\n",
                             indtype[incol], initems[incol]);
-
+            
             switch(indtype[incol]) {
             case D_I1_FORMAT:
             case D_I2_FORMAT:
@@ -584,6 +592,7 @@ create_full_ordertable()");
                 free(pointerstofree[npointerstofree]);
                 break;
             case D_R4_FORMAT:
+
                 if ((fbuffer = (float *) calloc(initems[incol], sizeof(float)))
                                 == NULL) {
                     SCTPUT("Error allocating memory in create_full_ordertable");
@@ -631,6 +640,7 @@ create_full_ordertable()");
                 free(pointerstofree[npointerstofree]);
                 break;
             case D_R8_FORMAT:
+
                 if ((dbuffer = (double *) calloc(initems[incol], sizeof(double)))
                                 == NULL){
                     SCTPUT("Error allocating memory in create_full_ordertable");
@@ -679,6 +689,7 @@ create_full_ordertable()");
                 break;
             case D_C_FORMAT:
                 size = initems[incol]*inbytes[incol];
+                char *cbuffer=NULL;
                 if ((cbuffer = (char *) calloc(initems[incol], inbytes[incol]))
                                 == NULL){
                     SCTPUT("Error allocating memory in create_full_ordertable");
@@ -765,13 +776,13 @@ create_full_ordertable()");
         outordercol = inordercol;
         outfibrecol = infibrecol;
         outxcol = inxcol;
-        outycol = inycol;
+        //outycol = inycol;
         outordfibcol = inordfibcol;
         outyfitcol = inyfitcol;
-        outresidcol = inresidcol;
+        //outresidcol = inresidcol;
     }
     outrows = inrows;
-    outcols = incols;
+    //outcols = incols;
 
     /* now run a loop over the orders/fibres and create the missing entries */
     for (ifibre=0; ifibre<=(ordpos->maxfibres-1); ifibre++) {
