@@ -1097,6 +1097,8 @@ void uves_parameters_new_string( cpl_parameterlist* list,
   check_nomsg(cpl_parameterlist_append(list,p));
 
  cleanup:
+  cpl_free(recipename);
+  cpl_free(paramname);
   return;
 }
 
@@ -1119,6 +1121,8 @@ void uves_parameters_new_double( cpl_parameterlist* list,
   check_nomsg(cpl_parameterlist_append(list,p));
 
   cleanup:
+  cpl_free(recipename);
+  cpl_free(paramname);
     return;
 }
 
@@ -1141,6 +1145,8 @@ void uves_parameters_new_float( cpl_parameterlist* list,
   check_nomsg(cpl_parameterlist_append(list,p));
 
   cleanup:
+  cpl_free(recipename);
+  cpl_free(paramname);
     return;
 }
 
@@ -1166,6 +1172,8 @@ void uves_parameters_new_range_int( cpl_parameterlist* list,
   check_nomsg(cpl_parameterlist_append(list,p));
 
   cleanup:
+  cpl_free(recipename);
+  cpl_free(paramname);
     return;
 }
 
@@ -1192,6 +1200,8 @@ void uves_parameters_new_range_float( cpl_parameterlist* list,
   check_nomsg(cpl_parameterlist_append(list,p));
 
   cleanup:
+  cpl_free(recipename);
+  cpl_free(paramname);
     return;
 }
 
@@ -1218,6 +1228,8 @@ void uves_parameters_new_range_double( cpl_parameterlist* list,
   check_nomsg(cpl_parameterlist_append(list,p));
 
   cleanup:
+  cpl_free(recipename);
+  cpl_free(paramname);
     return;
 }
 
@@ -1256,6 +1268,8 @@ int uves_parameters_get_boolean( const cpl_parameterlist * list,
   check_nomsg(result = cpl_parameter_get_bool( p));
                                                                                                                                                              
   cleanup:
+  cpl_free(recipename);
+  cpl_free(paramname);
     return result;
 }
 
@@ -1298,6 +1312,8 @@ double uves_parameters_get_double( cpl_parameterlist* list,
   check_nomsg(result = cpl_parameter_get_double(p));
 
   cleanup:
+  cpl_free(recipename);
+  cpl_free(paramname);
     return result;
 } 
 
