@@ -193,6 +193,8 @@ int flames_prepslitff(const cpl_frameset *SLITCAT, cpl_frameset **OUTCAT,
     do {
         if ((status = SCCGET(incat,0,filename,identifier,&entrynum)) != 0) {
             /* error getting catalog entry */
+            free(ordpos);
+            free(slitflats);
             return flames_midas_fail();
         }
         /* did I get a valid catalog entry? */
