@@ -157,10 +157,16 @@ flames_err shift_all_FF(allflats *allflatsin, orderpos *ordpos, double yshift,
      this x */
             /* bail out if the function call return an error status */
             if ((status = get_ordpos(ordpos, order, x, &ordercentre))!=NOERR) {
+            	free(fitdata.offset);
+            	free(fitdata.value);
+            	free(fitdata.sigma);
                 return(status);
             }
             myshiftdata->ordercentre = ordercentre;
             if ((status = get_ordslope(ordpos, order, x, &orderslope))!=NOERR) {
+            	free(fitdata.offset);
+            	free(fitdata.value);
+            	free(fitdata.sigma);
                 return(status);
             }
             myshiftdata->orderslope = orderslope;
@@ -182,6 +188,9 @@ flames_err shift_all_FF(allflats *allflatsin, orderpos *ordpos, double yshift,
                 fmvecbuf2 = myflatout->badpixel[0];
                 if ((status=calcshifts(allflatsin, shiftdata, iframe, ix, yshift))
                                 != NOERR) {
+                	free(fitdata.offset);
+                	free(fitdata.sigma);
+                	free(fitdata.value);
                     return(status);
                 }
                 /* loop over lit fibres in this frame */
@@ -203,6 +212,9 @@ flames_err shift_all_FF(allflats *allflatsin, orderpos *ordpos, double yshift,
                         if ((status=locatefibre(allflatsin, allflatsout, ordpos,
                                         shiftdata, iorder, ifibre, ix, yshift))
                                         != NOERR) {
+                        	free(fitdata.offset);
+                        	free(fitdata.sigma);
+                        	free(fitdata.value);
                             return(status);
                         }
                         /* loop over pixels belonging to the shifted fibre, only if
