@@ -22,76 +22,6 @@
  * $Date: 2010-09-24 09:32:02 $
  * $Revision: 1.26 $
  * $Name: not supported by cvs2svn $
- * $Log: not supported by cvs2svn $
- * Revision 1.24  2009/10/29 17:47:15  amodigli
- * set location of new red ccd's traps
- *
- * Revision 1.23  2007/08/21 13:08:26  jmlarsen
- * Removed irplib_access module, largely deprecated by CPL-4
- *
- * Revision 1.22  2007/07/23 06:37:44  amodigli
- * we now support also input data type CPL_TYPE_FLOAT
- *
- * Revision 1.21  2007/06/06 08:17:33  amodigli
- * replace tab with 4 spaces
- *
- * Revision 1.20  2007/04/24 12:50:29  jmlarsen
- * Replaced cpl_propertylist -> uves_propertylist which is much faster
- *
- * Revision 1.19  2007/01/16 10:26:52  jmlarsen
- * Fixed calloc -> cpl_calloc
- *
- * Revision 1.18  2007/01/15 15:10:01  jmlarsen
- * Fixed memory bug in deallocator
- *
- * Revision 1.17  2007/01/15 13:57:20  jmlarsen
- * Fixed crashing BLUE chips
- *
- * Revision 1.16  2007/01/10 12:35:59  jmlarsen
- * Added uves_get_badpix
- *
- * Revision 1.15  2006/11/15 15:02:14  jmlarsen
- * Implemented const safe workarounds for CPL functions
- *
- * Revision 1.13  2006/11/15 14:04:08  jmlarsen
- * Removed non-const version of parameterlist_get_first/last/next which is already
- * in CPL, added const-safe wrapper, unwrapper and deallocator functions
- *
- * Revision 1.12  2006/11/06 15:19:41  jmlarsen
- * Removed unused include directives
- *
- * Revision 1.11  2006/08/17 13:56:52  jmlarsen
- * Reduced max line length
- *
- * Revision 1.10  2006/08/17 09:16:30  jmlarsen
- * Removed CPL2 code
- *
- * Revision 1.9  2006/08/14 12:15:26  jmlarsen
- * Update to CPL3
- *
- * Revision 1.8  2006/08/10 10:49:06  jmlarsen
- * Removed workaround for cpl_image_get_bpm
- *
- * Revision 1.7  2006/08/08 11:27:18  amodigli
- * upgrade to CPL3
- *
- * Revision 1.6  2006/07/07 06:45:23  amodigli
- * added doc
- *
- * Revision 1.5  2006/07/03 14:20:39  jmlarsen
- * Exclude bad pixels from order tracing
- *
- * Revision 1.4  2006/07/03 12:58:34  jmlarsen
- * Support flagging instead of interpolating bad pixels
- *
- * Revision 1.3  2006/04/06 08:29:56  jmlarsen
- * Include self
- *
- * Revision 1.2  2005/12/19 16:17:56  jmlarsen
- * Replaced bool -> int
- *
- * Revision 1.1  2005/11/11 13:18:54  jmlarsen
- * Reorganized code, renamed source files
  *
  */
 
@@ -650,13 +580,11 @@ uves_correct_badpix(cpl_image *master_bias, uves_propertylist *header, int **bad
             
             uves_msg("Correcting window (%d, %d)-(%d, %d)", xstart, ystart, xend, yend);
 
-
             if(type == CPL_TYPE_DOUBLE) {
 
             for (x = xstart; x <= xend; x++) {
             for (y = ystart; y <= yend; y++) {
                 int pis_rejected;
-                double i1, i2;
                 
                 if (mark_bad)
                 {
@@ -670,8 +598,8 @@ uves_correct_badpix(cpl_image *master_bias, uves_propertylist *header, int **bad
                 {
                     double *master_bias_data;
 
-                    i1 = cpl_image_get(master_bias, x, ylow , &pis_rejected);
-                    i2 = cpl_image_get(master_bias, x, yhigh, &pis_rejected);
+                    double i1 = cpl_image_get(master_bias, x, ylow , &pis_rejected);
+                    double i2 = cpl_image_get(master_bias, x, yhigh, &pis_rejected);
                     
                     /* Write average */
                     
@@ -683,17 +611,14 @@ uves_correct_badpix(cpl_image *master_bias, uves_propertylist *header, int **bad
                 }
                 ncorrect += 1;
             }
+
             }
 
-
 	    } else {
 
-
             for (x = xstart; x <= xend; x++) {
             for (y = ystart; y <= yend; y++) {
                 int pis_rejected;
-                float i1, i2;
-                
                 if (mark_bad)
                 {
                     /* This is extremely slow with CPL2:
@@ -706,8 +631,8 @@ uves_correct_badpix(cpl_image *master_bias, uves_propertylist *header, int **bad
                 {
                     float *master_bias_data;
 
-                    i1 = cpl_image_get(master_bias, x, ylow , &pis_rejected);
-                    i2 = cpl_image_get(master_bias, x, yhigh, &pis_rejected);
+                    float i1 = cpl_image_get(master_bias, x, ylow , &pis_rejected);
+                    float i2 = cpl_image_get(master_bias, x, yhigh, &pis_rejected);
                     
                     /* Write average */
                     
@@ -719,12 +644,11 @@ uves_correct_badpix(cpl_image *master_bias, uves_propertylist *header, int **bad
                 }
                 ncorrect += 1;
             }
+
             }
 
-
 	    }
 
-
         }
         else
         {
