@@ -45,6 +45,7 @@
 #include <uves_corrbadpix.h>
 #include <uves_parameters.h>
 #include <uves.h>
+#include <uves_chip.h>
 #include <uves_dfs.h>
 #include <uves_pfits.h>
 #include <uves_qclog.h>
@@ -231,7 +232,7 @@ uves_mbias_process_chip(const cpl_imagelist *raw_images,
     }
     exposure_time /= nraw;
 
-    uves_pfits_set_extname(mbias_header,"Master bias");
+    //uves_pfits_set_extname(mbias_header,"Master bias");
     
     check( uves_pfits_set_exptime(mbias_header, exposure_time),
        "Error setting master bias exposure time");
