@@ -556,7 +556,7 @@ uves_mdark_process_chip(const cpl_imagelist *raw_images,
     } 
     check( uves_pfits_set_exptime(mdark_header, (max_exptime + min_exptime)/2),
        "Error setting master dark exposure time");
-    uves_pfits_set_extname(mdark_header,"Master dark");
+    //uves_pfits_set_extname(mdark_header,"Master dark");
     
   cleanup:
     uves_free_image(&current_dark);
