@@ -1506,8 +1506,8 @@ uves_orderpos_exe_body(cpl_frameset *frames,
             uves_propertylist_append_string(product_header,
                                             "HISTORY", " ");
         }
-        uves_pfits_set_extname(product_header,"Order table");
-        uves_pfits_set_extname(product_header,"Guess order table");
+        //uves_pfits_set_extname(product_header,"Order table");
+        //uves_pfits_set_extname(product_header,"Guess order table");
         sprintf(extname,"ORDER_TAB");
         uves_pfits_set_extname(table_header,extname);
         check(( cpl_free(product_filename),
