@@ -1207,7 +1207,7 @@ uves_physmod_exe_body(cpl_frameset *frames,
       }
 
       cpl_free(product_filename);
-      uves_pfits_set_extname(product_header,"Guess line table");
+      //uves_pfits_set_extname(product_header,"Guess line table");
       sprintf(extname,"LINE_GUESS_TAB");
       uves_pfits_set_extname(table_header,extname);
       check(( product_filename = uves_guess_line_table_filename(chip),
@@ -1252,7 +1252,7 @@ uves_physmod_exe_body(cpl_frameset *frames,
       /* Save guess order table, re-use product header */
 
       cpl_free(product_filename);        
-      uves_pfits_set_extname(product_header,"Guess order table");
+      //uves_pfits_set_extname(product_header,"Guess order table");
       sprintf(extname,"ORD_GUESS_TAB");
       uves_pfits_set_extname(table_header,extname);
       check(( product_filename = uves_guess_order_table_filename(chip),
