@@ -22,49 +22,6 @@
  * $Date: 2010-09-24 09:32:07 $
  * $Revision: 1.11 $
  * $Name: not supported by cvs2svn $
- * $Log: not supported by cvs2svn $
- * Revision 1.9  2007/06/06 08:17:33  amodigli
- * replace tab with 4 spaces
- *
- * Revision 1.8  2006/08/23 15:41:06  amodigli
- * removed warning from checks on line length
- *
- * Revision 1.7  2006/08/11 14:56:05  amodigli
- * removed Doxygen warnings
- *
- * Revision 1.6  2006/06/20 10:56:56  amodigli
- * cleaned output, added units
- *
- * Revision 1.5  2006/06/20 08:25:56  amodigli
- * fixed doxigen warnings
- *
- * Revision 1.4  2006/06/13 11:59:51  jmlarsen
- * Fixed doc. bug
- *
- * Revision 1.3  2006/06/08 11:01:50  amodigli
- * fixed some warnings
- *
- * Revision 1.2  2006/06/01 14:43:17  jmlarsen
- * Added missing documentation
- *
- * Revision 1.1  2006/02/03 07:46:30  jmlarsen
- * Moved recipe implementations to ./uves directory
- *
- * Revision 1.13  2006/01/20 10:05:49  jmlarsen
- * Inserted missing doxygen end tag
- *
- * Revision 1.12  2006/01/13 09:54:42  amodigli
- * Fixed some bugs: improved agreement with MIDAS version
- *
- * Revision 1.11  2006/01/09 14:05:42  amodigli
- * Fixed doxigen warnings
- *
- * Revision 1.10  2006/01/05 14:29:59  jmlarsen
- * Removed newline characters from output strings
- *
- * Revision 1.9  2005/12/20 08:11:44  jmlarsen
- * Added CVS  entry
- *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -378,11 +335,11 @@ register int jj=0;
 register int kk=0;
 
 int    evin=0;
-int    row=0;
+
 int    per[MAXPAR];
 double even=0.;
 double mjk=0.;
-double rowmax=0.;
+
 double hv[MAXPAR];
 
 
@@ -390,8 +347,8 @@ for ( ii = 0; ii < nfree; ii++ ) per[ii] = ii;     /* set permutation array */
 
 for ( jj = 0; jj < nfree; jj++ )                   /* in j-th column, ... */
    {
-   rowmax = fabs( matrix[jj][jj] );             /* determine row with ... */
-   row = jj;                                    /* largest element. */
+   double rowmax = fabs( matrix[jj][jj] );             /* determine row with ... */
+   int row = jj;                                    /* largest element. */
    for ( ii = jj + 1; ii < nfree; ii++ )
       {
       if ( fabs( matrix[ii][jj] ) > rowmax )
@@ -474,15 +431,8 @@ static double ERFCC( double xx )
 
 {
 
-double t=0.;
-double z=0.;
-double ans=0.;
-double zz=0.;
-double zozo=0.;
-
-
-z = fabs( xx );
-t = 1.0 / (1.0 + (0.5 * z));
+double z = fabs( xx );
+double t = 1.0 / (1.0 + (0.5 * z));
 
 /*
 ans = t * exp( -z * z - 1.26551223 + t * ( 1.00002368 + t *
@@ -500,19 +450,19 @@ however it works on SUSE Linux 6.xx on Intel (using g77)
 
 therefore this work around which seemed to solve the problem, KB 000522  */
 
-zz =  -z * z - 1.26551223 + t * ( 1.00002368 + t *
+double zz =  -z * z - 1.26551223 + t * ( 1.00002368 + t *
                       ( 0.37409196 + t * ( 0.09678418 + t *
                       (-0.18628806 + t * ( 0.27886807 + t *
                       (-1.13520398 + t * ( 1.48851587 + t *
                       (-0.82215223 + t * 0.17087277 ))))))));
 
-
+double zozo=0.;
 if (zz < -500.0)
    zozo = 0.0;
 else
    zozo = exp(zz);
 
-ans = t * zozo;
+double ans = t * zozo;
 
 
 return  (xx >= 0.0 ? ans : 2.0 - ans);
@@ -575,9 +525,9 @@ double tempp=0.;
 double x1=0.;
 double x2=0.;
 double zz=0.;
-double zx=0.;
-double dv1=0.; 
-double dv2=0.;
+
+
+
 static double sqrt_2;
 
 register int jj=0;
@@ -599,13 +549,14 @@ zz = tempp / gpar[2] ;
 if ( ((zz * zz) - 50.0) < 0.0 )
    { 
    deriv[0] = (GAUSFU( xdat, gpar ) - gpar[3]) / gpar[0];
-
-   zx = (-x1) * x1;
+   double zx = (-x1) * x1;
+   double dv1=0.;
    if ( zx < -200.0)        /*  zx  always < 0 */
       dv1 = 0.0;        /*  e**(-200)  is = 0.0 ... */
    else
       dv1 = exp(zx);
    zx = (-x2) * x2;
+   double dv2=0.;
    if ( zx < -200.0)
       dv2 = dv1;
    else
@@ -646,17 +597,17 @@ static float FCHIS(double *data,int ndim,int nfree,int mode,double *dfit) {
 
 register int ii=0;
 
-double diff=0.;
-double weight=0.;
-double chisq=0.;
+
+
 
 
 if ( nfree > 0 )
    {
-   chisq = 0.0;
+   double chisq = 0.0;
 
    for (ii=0; ii<ndim; ii++)
       {
+	   double weight=0.;
       if ( mode < 0 )
          {
          if ( *data < 0 )
@@ -669,7 +620,7 @@ if ( nfree > 0 )
       else
          weight = 1.0;
 
-      diff = (*data) - (*dfit);
+      double diff = (*data) - (*dfit);
       data++;  dfit++;
       chisq += weight * diff * diff;
       }
@@ -857,7 +808,7 @@ register int iy=0;
 int nrx=0;
 int nry=0;
  
-double sum=0;
+
 
 
 
@@ -889,7 +840,7 @@ p_img += nxdim * (image[2] + lnew[0]);
 
 for (ix=0; ix<nrx; ix++)
    {
-   sum = 0.0;
+   double sum = 0.0;
    for (iy=0; iy<nry*nxdim; iy+=nxdim) sum += p_img[iy];
    p_img++;
    *krx++ = sum;
@@ -929,7 +880,7 @@ register int iy=0;
 int nrx=0;
 int nry=0;
 
-double sum=0;
+
 
 
 
@@ -960,7 +911,7 @@ p_img += (nxdim * image[2]) + (image[0] + lnew[0]);
 
 for (iy=0; iy<nry; iy++)
    {
-   sum = 0.0;
+   double sum = 0.0;
    for (ix=0; ix<nrx; ix++) sum += p_img[ix];
    p_img += nxdim;
    *kry++ = sum;
@@ -1008,8 +959,8 @@ int indx=0;
 
 double dxk=0.;
 double diff=0.;
-double drmn=0.;
-double drmx=0.;
+
+
 double sum=0.;
 double  *work=NULL;
 
@@ -1025,7 +976,7 @@ work = (double *) cpl_calloc( ndim , sizeof( double ));
 /* find maximum and minimum derivative of MARG */
 
 imin = imax = 0;
-drmn = drmx = 0.0;
+double drmn = 0., drmx = 0.0;
 for (ii = ibgn; ii < iend; ii++ )
     {
     diff = marg[ii+1] - marg[ii-1];
