@@ -244,16 +244,16 @@ integrate_noise(const double *spectrum_data_double,
 cpl_parameterlist *
 uves_rebin_define_parameters(void)
 {
-    const char *name = "";
-    char *full_name = NULL;
-    cpl_parameter *p = NULL;
+
+
+
     cpl_parameterlist *parameters = NULL;
-    
     parameters = cpl_parameterlist_new();
     
     {
-    name = "wavestep";
-    full_name = uves_sprintf("%s.%s", UVES_REBIN_ID, name);
+    cpl_parameter *p = NULL;
+    const char* name = "wavestep";
+    char* full_name = uves_sprintf("%s.%s", UVES_REBIN_ID, name);
     uves_parameter_new_range(p, full_name,
                  CPL_TYPE_DOUBLE,
                  "The bin size (in w.l.u.) in wavelength space. "
