@@ -985,7 +985,7 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
                     cpl_free(product_filename);
                     check( product_filename = uves_response_curve_filename(chip),
                        "Error getting filename");
-                    uves_pfits_set_extname(response_header,"instrument response");
+                    //uves_pfits_set_extname(response_header,"instrument response");
 
                     check( uves_frameset_insert(
                            frames,
@@ -1015,7 +1015,7 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
                     check( product_filename = 
                        uves_response_curve_2d_filename(chip), 
                        "Error getting filename");
-                    uves_pfits_set_extname(response_header_2d,"2D instrument response");
+                    //uves_pfits_set_extname(response_header_2d,"2D instrument response");
                     check( uves_frameset_insert(
                            frames,
                            response_orders,
@@ -1054,7 +1054,7 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
                    prod_catg=UVES_RED_STD(chip);
 
                 }
-                uves_pfits_set_extname(spectrum_header,"reduced spectrum");
+                //uves_pfits_set_extname(spectrum_header,"reduced spectrum");
                 check( uves_frameset_insert(frames,
                             reduced_spectrum,
                             CPL_FRAME_GROUP_PRODUCT,
@@ -1087,7 +1087,7 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
                     check( product_filename = 
                        uves_response_efficiency_filename(chip),
                        "Error getting filename");
-                    uves_pfits_set_extname(efficiency_header,"efficiency");
+                    //uves_pfits_set_extname(efficiency_header,"efficiency");
                     sprintf(extname,"EFFICIENCY");
                     uves_pfits_set_extname(table_header,extname);
                     check( uves_frameset_insert(
@@ -1118,7 +1118,7 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
                 check( product_filename = 
                    uves_response_bkg_standard_filename(chip), 
                    "Error getting filename");
-                uves_pfits_set_extname(rotated_header[raw_index],"background");
+                //uves_pfits_set_extname(rotated_header[raw_index],"background");
                 check( uves_frameset_insert(frames,
                             background,
                             CPL_FRAME_GROUP_PRODUCT,
@@ -1146,7 +1146,7 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
                 check( product_filename = 
                    uves_order_extract_qc_standard_filename(chip), 
                    "Error getting filename");
-                uves_pfits_set_extname(rotated_header[raw_index],"quality control table");
+                //uves_pfits_set_extname(rotated_header[raw_index],"quality control table");
                 sprintf(extname,"QC_INFO");
                 uves_pfits_set_extname(table_header,extname);
 
