@@ -237,6 +237,9 @@ uves_wavecal_firstsolution(cpl_table *linetable,
                       NULL, NULL,        /* mse, chi^2 */
                       NULL,              /* variance pol. */
                       -1, -1);           /* kappa */
+    cpl_table_set_column_unit(linetable,"X","pix");
+    cpl_table_set_column_unit(linetable,"Ynew","pix");
+    cpl_table_set_column_unit(linetable,"Order"," ");
 
     if (cpl_error_get_code() != CPL_ERROR_NONE) /* Singular matrix, or too few points */
         {
